; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| Fatalites |--------------------------------------------------------
;[Command]
;name = "JimBeamEasy"
;command = ~D, B, s
;time = 25

;[Command]
;name = "StubbsEasy"
;command = ~D, F, s
;time = 25

;[Command]
;name = "AcidEasy"
;command = ~B, F, s
;time = 25

[Command]
name = "JimBeam"
command = ~D, DB, B, s ;D, DB, B, s
time = 25

[Command]
name = "Stubbs"
command = ~D, DF, F, s ;D, DF, F, s
time = 25

[Command]
name = "Acid"
command = ~B, F, s ;B, s
time = 25

;-| Super Motions |--------------------------------------------------------
[Command]
name = "Atomic_x"
command = ~D, DF, F, D, DF, F, x
time = 25

[Command]
name = "Atomic_y"
command = ~D, DF, F, D, DF, F, y
time = 25

[Command]
name = "Atomic_z"
command = ~D, DF, F, D, DF, F, z
time = 25

[Command]
name = "Suntrup_a"
command = ~D, DF, F, D, DF, F, a
time = 25

[Command]
name = "Suntrup_b"
command = ~D, DF, F, D, DF, F, b
time = 25

[Command]
name = "Suntrup_c"
command = ~D, DF, F, D, DF, F, c
time = 25

[Command]
name = "Missle"
command = ~D, DB, B, x+y+z
time = 25

[Command]
name = "Alex"
command = ~D, DB, B, D, DB, B, a
time = 25

[Command]
name = "Alex"
command = ~D, DB, B, D, DB, B, b
time = 25

[Command]
name = "Alex"
command = ~D, DB, B, D, DB, B, c
time = 25

;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_xy"
command = ~F, D, DF, x+y

[Command]
name = "QCF_x"
command = ~D, DF, F, x
time = 15

[Command]
name = "QCF_y"
command = ~D, DF, F, y
time = 15

[Command]
name = "QCF_z"
command = ~D, DF, F, z
time = 15

[Command]
name = "QCF_a"
command = ~D, DF, F, a
time = 15

[Command]
name = "QCF_b"
command = ~D, DF, F, b
time = 15

[Command]
name = "QCF_c"
command = ~D, DF, F, c
time = 15

[Command]
name = "Charge_x"
command = ~35B, F, x
time = 45

[Command]
name = "Charge_y"
command = ~35B, F, y
time = 45

[Command]
name = "Charge_z"
command = ~35B, F, z
time = 45

[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "QCB_a"
command = ~D, DB, B, a
time = 15

[Command]
name = "QCB_b"
command = ~D, DB, B, b
time = 15

[Command]
name = "QCB_c"
command = ~D, DB, B, b
time = 15

[Command]
name = "QCB_x"
command = ~D, DB, B, x
time = 15

[Command]
name = "QCB_y"
command = ~D, DB, B, y
time = 15

[Command]
name = "QCB_z"
command = ~D, DB, B, z
time = 15

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

[Command]
name = "BottleChop"
command = B, B, B, a
time = 35

[Command]
name = "Yoshi"
command = B, B, B, b
time = 35

[Command]
name = "Windmill"
command = B, B, B, c
time = 35

[Command]
name = "Belch_x"
command = ~B, D, F, x
time = 15

[Command]
name = "Belch_y"
command = ~B, D, F, y
time = 15

[Command]
name = "Belch_z"
command = ~B, D, F, z
time = 15

[Command]
name = "Fount_x"
command = ~B, D, DB, x
time = 15

[Command]
name = "Fount_y"
command = ~B, D, DB, y
time = 15

[Command]
name = "Fount_z"
command = ~B, D, DB, z
time = 15

[Command]
name = "Fly_a"
command = ~B, D, DB, a
time = 15

[Command]
name = "Fly_b"
command = ~B, D, DB, b
time = 15

[Command]
name = "Fly_c"
command = ~B, D, DB, c
time = 15

[Command]
name = "Air_Fly"
command = ~D, DB, B, a
time = 15

[Command]
name = "Air_Fly"
command = ~D, DB, B, b
time = 15

[Command]
name = "Air_Fly"
command = ~D, DB, B, c
time = 15

[Command]
name = "Stomp"
command = D, a
time = 8

[Command]
name = "Stomp"
command = D, b
time = 8

[Command]
name = "Stomp"
command = D, c
time = 8

[Command]
name = "HopBack"
command = B, a+x
time = 20

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "chargex"
command = /$x

[Command]
name = "releasex"
command = ~x
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Throws |--------------------------------------------------------------
[Command]
name = "Bottle"
command = x+y
time = 8

[Command]
name = "Piston"
command = y+z
time = 8

[Command]
name = "Yoga"
command = a+b
time = 8

[Command]
name = "Blanka"
command = b+c
time = 8

;-| CPU ONLY (DUMMY MOVES ONLY THE COMPUTER CAN DO THAT ACTIVATE HIS AI |-----------------------
[Command]
name = "CPU1"
command = D, D, U, U, D, U
time = 1

[Command]
name = "CPU2"
command = D, U, U, D, D, U
time = 1

[Command]
name = "CPU3"
command = D, D, D, U, U, U
time = 1

[Command]
name = "CPU4"
command = U, D, D, U, U, U
time = 1

[Command]
name = "CPU5"
command = D, D, U, U, D, D
time = 1

[Command]
name = "CPU6"
command = U, D, D, D, D, U
time = 1

[Command]
name = "CPU7"
command = U, U, U, U, U, D
time = 1

[Command]
name = "CPU8"
command = U, U, U, U, D, U
time = 1

[Command]
name = "CPU9"
command = U, U, U, D, U, U
time = 1

[Command]
name = "CPU10"
command = U, U, D, U, U, U
time = 1

[Command]
name = "CPU11"
command = U, D, U, U, U, U
time = 1

[Command]
name = "CPU12"
command = D, U, D, U, D, U
time = 1

[Command]
name = "CPU13"
command = U, U, D, U, U, U, U
time = 1

[Command]
name = "CPU14"
command = U, D, D, U, U, U, U
time = 1

[Command]
name = "CPU15"
command = D, U, D, U, U, U, D
time = 1

[Command]
name = "CPU16"
command = D, D, D, U, U, U, U
time = 1

[Command]
name = "CPU17"
command = U, U, D, U, U, D, D
time = 1

[Command]
name = "CPU18"
command = D, D, D, U, D, D, D
time = 1

[Command]
name = "CPU19"
command = U, D, D, U, D, U, D
time = 1

[Command]
name = "CPU20"
command = D, D, D, U, U, U, D
time = 1

[Command]
name = "CPU21"
command = U, D, U, D, U, U, U
time = 1

[Command]
name = "CPU22"
command = U, U, U, U, U, U, U
time = 1

[Command]
name = "CPU23"
command = D, D, D, D, D, D, D
time = 1

[Command]
name = "CPU24"
command = D, D, D, D, D, D, U
time = 1

[Command]
name = "CPU25"
command = D, D, D, D, D, U, D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

[State -1, AITurnOn]
type = VarSet
triggerall = var(21) != 1
trigger1  = command = "CPU1"
trigger2  = command = "CPU2"
trigger3  = command = "CPU3"
trigger4  = command = "CPU4"
trigger5  = command = "CPU5"
trigger6  = command = "CPU6"
trigger7  = command = "CPU7"
trigger8  = command = "CPU8"
trigger9  = command = "CPU9"
trigger10 = command = "CPU10"
trigger11 = command = "CPU11"
trigger12 = command = "CPU12"
trigger13 = command = "CPU13"
trigger14 = command = "CPU14"
trigger15 = command = "CPU15"
trigger16 = command = "CPU16"
trigger17 = command = "CPU17"
trigger18 = command = "CPU18"
trigger19 = command = "CPU19"
trigger20 = command = "CPU20"
trigger21 = command = "CPU21"
trigger22 = command = "CPU22"
trigger23 = command = "CPU23"
trigger24 = command = "CPU24"
trigger25 = command = "CPU25"
v = 21
value = 1

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "HopBack"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Alex Grab
[State -1, Alex]
type = ChangeState
value = 4050
triggerall = power >= 750
triggerall = command = "Alex"
trigger1 = ctrl
trigger1 = statetype = S
trigger2 = ctrl
trigger2 = statetype = C
trigger3 = stateno = 1120
trigger4 = stateno = 1111

;===========================================================================
;---------------------------------------------------------------------------
;Standing Jab
[State -1, Stand Light Punch]
type = ChangeState
value = 1000
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = command != "QCF_x"
triggerall = command != "QCB_x"
triggerall = command != "Fount_x"
triggerall = command != "Charge_x"
triggerall = command != "Belch_x"
triggerall = command != "Atomic_x"
triggerall = command != "Missle"
triggerall = command != "Bottle"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 1000
trigger2 = time > 6

;---------------------------------------------------------------------------
;Standing Headbutt
[State -1, Stand Strong Punch]
type = ChangeState
value = 1010
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = command != "QCF_y"
triggerall = command != "QCB_y"
triggerall = command != "Fount_y"
triggerall = command != "Charge_y"
triggerall = command != "Belch_y"
triggerall = command != "Atomic_y"
triggerall = command != "Missle"
triggerall = command != "Bottle"
triggerall = command != "Piston"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 1000) && time > 5
trigger3 = (stateno = 1030) && time > 6

;---------------------------------------------------------------------------
;Sloppy Hook
[State -1, Stand Hook]
type = ChangeState
value = 1020
triggerall = command = "z"
triggerall = command != "holddown"
triggerall = command != "QCF_z"
triggerall = command != "QCB_z"
triggerall = command != "Fount_z"
triggerall = command != "Charge_z"
triggerall = command != "Belch_z"
triggerall = command != "Atomic_z"
triggerall = command != "Missle"
triggerall = command != "Piston"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Standing Toe Step
[State -1, Stand Toe Step]
type = ChangeState
value = 1030
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = command != "QCF_a"
triggerall = command != "Fly_a"
triggerall = command != "BottleChop"
triggerall = command != "Suntrup_a"
triggerall = command != "Yoga"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 1000) && time > 7
trigger3 = (stateno = 1030) && time > 9

;---------------------------------------------------------------------------
;Standing Shin Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 1040
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = command != "QCF_b"
triggerall = command != "Fly_b"
triggerall = command != "Yoshi"
triggerall = command != "Suntrup_b"
triggerall = command != "Blanka"
triggerall = command != "Yoga"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 1000) && time > 5
trigger3 = (stateno = 1030) && time > 6

;---------------------------------------------------------------------------
;Standing Kick
[State -1, Standing Kick]
type = ChangeState
value = 1050
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = command != "QCF_c"
triggerall = command != "Fly_c"
triggerall = command != "Windmill"
triggerall = command != "Suntrup_c"
triggerall = command != "Blanka"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
triggerall = command != "JimBeam"
triggerall = command != "Stubbs"
triggerall = command != "Acid"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Punch
[State -1, Crouching Punch]
type = ChangeState
value = 1100
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Sleep
[State -1, Sleep]
type = ChangeState
value = 1110
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Puke
[State -1, Puke]
type = ChangeState
value = 1120
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Slide
[State -1, Crouching Slide]
type = ChangeState
value = 1130
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
;trigger2 = (stateno = 1100) || (stateno = 1140)
;trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Kick
[State -1, Crouching Kick]
type = ChangeState
value = 1140
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 1100) || (stateno = 1140)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Roll
[State -1, Crouching Roll]
type = ChangeState
value = 1150
triggerall = command = "c"
;triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jumping Punch
[State -1, Jump Punch]
type = ChangeState
value = 1200
triggerall = command = "x"
triggerall = command != "QCF_x"
triggerall = command != "Charge_x"
triggerall = command != "Atomic_x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1200
trigger2 = statetime >= 7

;---------------------------------------------------------------------------
;Jumping Smash
[State -1, Jump Smash]
type = ChangeState
value = 1210
triggerall = command = "y"
triggerall = command != "QCF_y"
triggerall = command != "Charge_y"
triggerall = command != "Atomic_y"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jumping Belly Flop
[State -1, Jump Bellyflop]
type = ChangeState
value = 1220
triggerall = command = "z"
triggerall = command != "QCF_z"
triggerall = command != "Charge_z"
triggerall = command != "Atomic_z"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jumping Kick
[State -1, Jump Kick]
type = ChangeState
value = 1230
triggerall = command = "a"
triggerall = command != "Air_Fly"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1200
trigger2 = statetime >= 7

;---------------------------------------------------------------------------
;Jumping Butt Bump
;󒆋LbN
[State -1, Jump Buttbump]
type = ChangeState
value = 1240
triggerall = command = "b"
triggerall = command != "Air_Fly"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jumping Spear
;󒆋-LbN
[State -1, Jump Spear]
type = ChangeState
value = 1250
triggerall = command = "c"
triggerall = command != "Air_Fly"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Mega Buster
[State -1, MegaBuster]
type = ChangeState
value = 2020
triggerall = command = "QCF_x"
triggerall = command != "Belch_x"
triggerall = command != "Atomic_x"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Beer Beam
[State -1, BeerBeam]
type = ChangeState
value = 2000
triggerall = command = "QCF_y"
triggerall = command != "Belch_y"
triggerall = command != "Atomic_y"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Vertical Beer Beam
[State -1, VBeerBeam]
type = ChangeState
value = 2010
triggerall = command = "QCF_z"
triggerall = command != "Belch_z"
triggerall = command != "Atomic_z"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Slow Rolling Keg
[State -1, RollKeg1]
type = ChangeState
value = 2130
triggerall = command = "QCB_x"
triggerall = command != "Fount_x"
triggerall = command != "Missle"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Medium Rolling Keg
[State -1, RollKeg2]
type = ChangeState
value = 2131
triggerall = command = "QCB_y"
triggerall = command != "Fount_y"
triggerall = command != "Missle"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Fast Rolling Keg
[State -1, RollKeg3]
type = ChangeState
value = 2132
triggerall = command = "QCB_z"
triggerall = command != "Fount_z"
triggerall = command != "Missle"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Beer Belch1
[State -1, Belch1]
type = ChangeState
value = 2030
triggerall = command = "Belch_x"
triggerall = p2stateno != 6083
triggerall = Var(49) >= 1
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Beer Belch2
[State -1, Belch2]
type = ChangeState
value = 2031
triggerall = command = "Belch_y"
triggerall = p2stateno != 6083
triggerall = Var(49) >= 1
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Beer Belch3
[State -1, Belch3]
type = ChangeState
value = 2032
triggerall = command = "Belch_z"
triggerall = p2stateno != 6083
triggerall = Var(49) >= 1
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Beer Fountain1
[State -1, Fount1]
type = ChangeState
value = 2100
triggerall = command = "Fount_x"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Beer Fountain2
[State -1, Fount2]
type = ChangeState
value = 2101
triggerall = command = "Fount_y"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Beer Fountain3
[State -1, Fount3]
type = ChangeState
value = 2102
triggerall = command = "Fount_z"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Short Sumo Headbutt
[State -1, ShortSumo]
type = ChangeState
value = 2090
triggerall = command = "Charge_x"
triggerall = ctrl
trigger1 = statetype = S
trigger2 = statetype = A

;---------------------------------------------------------------------------
;Medium Sumo Headbutt
[State -1, MediumSumo]
type = ChangeState
value = 2091
triggerall = command = "Charge_y"
triggerall = ctrl
trigger1 = statetype = S
trigger2 = statetype = A

;---------------------------------------------------------------------------
;Long Sumo Headbutt
[State -1, LongSumo]
type = ChangeState
value = 2092
triggerall = command = "Charge_z"
triggerall = ctrl
trigger1 = statetype = S
trigger2 = statetype = A

;---------------------------------------------------------------------------
;Bottle Chop
[State -1, Bottle Chop]
type = ChangeState
value = 2050
triggerall = command = "BottleChop"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Yoshimitsu Kick
[State -1, YoshiKick]
type = ChangeState
value = 2060
triggerall = command = "Yoshi"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Windmill Punch
[State -1, Windmill]
type = ChangeState
value = 2120
triggerall = command = "Windmill"
triggerall = power >= 333
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Beer Squad1
[State -1, BeerSquad1]
type = ChangeState
value = 2080
triggerall = command = "QCF_a"
triggerall = command != "Suntrup_a"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Beer Squad2
[State -1, BeerSquad2]
type = ChangeState
value = 2081
triggerall = command = "QCF_b"
triggerall = command != "Suntrup_b"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Beer Squad3
[State -1, BeerSquad3]
type = ChangeState
value = 2082
triggerall = command = "QCF_c"
triggerall = command != "Suntrup_c"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Air Beer Can
[State -1, AirBeerCan]
type = ChangeState
value = 2040
triggerall = command = "QCF_x"
triggerall = command != "Atomic_x"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Air 2by4
[State -1, Air2by4]
type = ChangeState
value = 2041
triggerall = command = "QCF_y"
triggerall = command != "Atomic_y"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Air 40
[State -1, Air40]
type = ChangeState
value = 2042
triggerall = command = "QCF_z"
triggerall = command != "Atomic_z"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Fly 1
[State -1, Fly1]
type = ChangeState
value = 2111
triggerall = command = "Fly_a"
triggerall = ctrl
trigger1 = statetype = S

;---------------------------------------------------------------------------
;Fly 2
[State -1, Fly2]
type = ChangeState
value = 2112
triggerall = command = "Fly_b"
triggerall = ctrl
trigger1 = statetype = S

;---------------------------------------------------------------------------
;Fly 3
[State -1, Fly3]
type = ChangeState
value = 2113
triggerall = command = "Fly_c"
triggerall = ctrl
trigger1 = statetype = S

;---------------------------------------------------------------------------
;Fly 1
[State -1, Fly1]
type = ChangeState
value = 2114
triggerall = ctrl
triggerall = statetype = A
triggerall = power >= 50
trigger1 = command = "Air_Fly"

;---------------------------------------------------------------------------
;Atomic Belch 1
[State -1, Atomic1]
type = ChangeState
value = 3020
triggerall = ctrl
triggerall = statetype = S
triggerall = power >= 1000
trigger1 = command = "Atomic_x"

;---------------------------------------------------------------------------
;Atomic Belch 2-1
[State -1, Atomic2-1]
type = ChangeState
value = 3030
triggerall = ctrl
triggerall = statetype = S
triggerall = power >= 2000
trigger1 = command = "Atomic_y"

;---------------------------------------------------------------------------
;Atomic Belch 2-2
[State -1, Atomic2-2]
type = ChangeState
value = 3020
triggerall = ctrl
triggerall = statetype = S
triggerall = power < 2000
triggerall = power >= 1000
trigger1 = command = "Atomic_y"

;---------------------------------------------------------------------------
;Atomic Belch 3-1
[State -1, Atomic3-1]
type = ChangeState
value = 3040
triggerall = ctrl
triggerall = statetype = S
triggerall = power >= 3000
trigger1 = command = "Atomic_z"

;---------------------------------------------------------------------------
;Atomic Belch 3-2
[State -1, Atomic3-2]
type = ChangeState
value = 3030
triggerall = ctrl
triggerall = statetype = S
triggerall = power < 3000
triggerall = power >= 2000
trigger1 = command = "Atomic_z"

;---------------------------------------------------------------------------
;Atomic Belch 3-3
[State -1, Atomic3-3]
type = ChangeState
value = 3020
triggerall = ctrl
triggerall = statetype = S
triggerall = power < 2000
triggerall = power >= 1000
trigger1 = command = "Atomic_z"

;---------------------------------------------------------------------------
;Suntrup Smash 1
[State -1, Suntrup1]
type = ChangeState
value = 3000
triggerall = ctrl
triggerall = statetype = S
triggerall = power >= 1000
trigger1 = command = "Suntrup_a"

;---------------------------------------------------------------------------
;Suntrup Smash 2
[State -1, Suntrup2]
type = ChangeState
value = 3004
triggerall = ctrl
triggerall = statetype = S
triggerall = power >= 2000
trigger1 = command = "Suntrup_b"

;---------------------------------------------------------------------------
;Suntrup Smash 3
[State -1, Suntrup3]
type = ChangeState
value = 3009
triggerall = ctrl
triggerall = statetype = S
triggerall = power >= 3000
trigger1 = command = "Suntrup_c"

;---------------------------------------------------------------------------
;Super Air Can 
[State -1, SuperCan]
type = ChangeState
value = 3100
triggerall = ctrl
triggerall = statetype = A
triggerall = power >= 1000
trigger1 = command = "Atomic_x"

;---------------------------------------------------------------------------
;Super Air 2by4 1 
[State -1, Super2by41]
type = ChangeState
value = 3110
triggerall = ctrl
triggerall = statetype = A
triggerall = power >= 2000
trigger1 = command = "Atomic_y"

;---------------------------------------------------------------------------
;Super Air 2by4 2 
[State -1, Super2by42]
type = ChangeState
value = 3100
triggerall = ctrl
triggerall = statetype = A
triggerall = power < 2000
triggerall = power >= 1000
trigger1 = command = "Atomic_y"

;---------------------------------------------------------------------------
;Super Air 40 1 
[State -1, Super401]
type = ChangeState
value = 3120
triggerall = ctrl
triggerall = statetype = A
triggerall = power >= 3000
trigger1 = command = "Atomic_z"

;---------------------------------------------------------------------------
;Super Air 40 2 
[State -1, Super402]
type = ChangeState
value = 3110
triggerall = ctrl
triggerall = statetype = A
triggerall = power < 3000
triggerall = power >= 2000
trigger1 = command = "Atomic_z"

;---------------------------------------------------------------------------
;Super Air 40 3 
[State -1, Super403]
type = ChangeState
value = 3100
triggerall = ctrl
triggerall = statetype = A
triggerall = power < 2000
triggerall = power >= 1000
trigger1 = command = "Atomic_z"

;---------------------------------------------------------------------------
;Beer Missle
[State -1, Missle]
type = ChangeState
value = 3019
triggerall = ctrl
triggerall = statetype = S
triggerall = power >= 3000
trigger1 = command = "Missle"

;---------------------------------------------------------------------------
;Bottle Smash
[State -1, Bottle]
type = ChangeState
value = 4010
triggerall = command = "Bottle"
triggerall = statetype = S
triggerall = ctrl
;triggerall = stateno != 100
trigger1 = command = "holdfwd"
;trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
;trigger1 = p2movetype != H
trigger2 = command = "holdback"
;trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
;trigger2 = p2movetype != H

;---------------------------------------------------------------------------
;Piston Grab
[State -1, Piston]
type = ChangeState
value = 4040
triggerall = command = "Piston"
triggerall = statetype = S
triggerall = ctrl
;triggerall = stateno != 100
trigger1 = command = "holdfwd"
;trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
;trigger1 = p2movetype != H
trigger2 = command = "holdback"
;trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
;trigger2 = p2movetype != H

;---------------------------------------------------------------------------
;Yoga Nuggie
[State -1, Yoga]
type = ChangeState
value = 4000
triggerall = command = "Yoga"
triggerall = statetype = S
triggerall = ctrl
;triggerall = stateno != 100
trigger1 = command = "holdfwd"
;trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
;trigger1 = p2movetype != H
trigger2 = command = "holdback"
;trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
;trigger2 = p2movetype != H

;---------------------------------------------------------------------------
;Blanka Bite
[State -1, Blanka]
type = ChangeState
value = 4030
triggerall = command = "Blanka"
triggerall = statetype = S
triggerall = ctrl
;triggerall = stateno != 100
trigger1 = command = "holdfwd"
;trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
;trigger1 = p2movetype != H
trigger2 = command = "holdback"
;trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
;trigger2 = p2movetype != H

;--------------------------------------------------------------------
[State -1]; JimBeam
type = Changestate
value = 9010
trigger1 = p2stateno = 9998
trigger2 = p2stateno = 9010
triggerall = command = "JimBeam"
triggerall = ctrl = 1
triggerall = P2statetype = S
triggerall = Statetype = S
;triggerall = p2bodyDist X > 40
triggerall = p2bodyDist X < 128

;--------------------------------------------------------------------
[State -1]; Stubbs
type = Changestate
value = 9020
trigger1 = p2stateno = 9998
trigger2 = p2stateno = 9010
triggerall = command = "Stubbs"
triggerall = ctrl = 1
triggerall = P2statetype = S
triggerall = Statetype = S
triggerall = p2bodyDist X < 32

;--------------------------------------------------------------------
[State -1, Acid]
type = ChangeState
value = 8200
triggerall = command = "Acid"
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2life < 10
triggerall = P2statetype = S
triggerall = p2bodydist X < 101
trigger1   = p2stateno = 9998
trigger1   = P2statetype = S
trigger2   = p2stateno = 9010
trigger2   = P2statetype = S
trigger3   = p2stateno = 9998
trigger3   = P2statetype = C
trigger4   = p2stateno = 9010
trigger4   = P2statetype = C
